@@ -1,7 +1,8 @@
 ###
-### JET.COLORS.R - Create a vector of colors beginning with dark blue, ranging
-###                through shades of blue, cyan, green, yellow and red, and
-###                ending with dark red.
+### $Id: jet.colors.R 29 2022-05-30 23:02:22Z proebuck $
+###
+### Create a vector of colors beginning with dark blue, ranging through
+### shades of blue, cyan, green, yellow and red, and ending with dark red.
 ###
 
 DEFAULT.COLORMAP.SIZE <- 64
@@ -31,7 +32,7 @@ jet <- function(m = DEFAULT.COLORMAP.SIZE) {
     J[g, 2] <- u[seq(along = g)]
     J[b, 3] <- u[seq(length(u)-length(b)+1, length(u))]
 
-    return(J)
+    J
 }
 
 
