@@ -1,5 +1,7 @@
 ###
-### ZZZ.R
+### $Id: zzz.R 28 2022-05-30 20:51:07Z proebuck $
+###
+### Hooks called as package is loaded, attached, detatched, and unloaded.
 ###
 
 
@@ -41,20 +43,14 @@
 
 ##-----------------------------------------------------------------------------
 .onLoad <- function(libname, pkgname) {
-    ## In case namespace is loaded (via import) by package that doesn't depend
-    ## on S4 methods and used in a session with non-default set of packages
-    require(methods)
-
     ## Create environment for internal usage
     environment(.MatlabNamespaceEnv) <- asNamespace("matlab")
 
     ## Load internal variables
     assign("savedTime", 0, envir=.MatlabNamespaceEnv)
 
-    ## Allow no changes or additions to environment
-    lockEnvironment(.MatlabNamespaceEnv, bindings=TRUE)
-
-    ## Only allow internal vars to change
-    unlockBinding("savedTime", .MatlabNamespaceEnv)
+    ## Allow no changes or additions to environment,
+    ## but allow its internal vars to change
+    lockEnvironment(.MatlabNamespaceEnv)
 }
 
